@@ -21,22 +21,6 @@ def _refactor_helper(refactor_func, input_src, change_spec) -> str:
         os.remove(ntf.name)
 
 
-class TestRefactorDemo(unittest.TestCase):
-    change_spec = {}
-
-    def test_refactor_demo(self):
-        input_src = '''
-        old_api()
-        '''
-        expected_src = '''
-        new_api()
-        '''
-        input_src = textwrap.dedent(input_src).strip() + '\n'
-        expected_src = textwrap.dedent(expected_src).strip() + '\n'
-        output_src = _refactor_helper(refactor_demo, input_src, self.change_spec)
-        self.assertEqual(output_src, expected_src)
-
-
 class TestRefactorImport(unittest.TestCase):
     def _run(self, change_spec, input_src, expected_src):
         input_src = textwrap.dedent(input_src).strip() + '\n'
@@ -210,11 +194,19 @@ class TestArgsToKwargs(unittest.TestCase):
     def test_args_to_kwargs(self):
         input_src = '''
         paddle.add(1,2)
-        paddle.add(1,y=2)
+        paddle.add(1, 2)
+        paddle.add(1, y=2)
+        paddle.add(1)
+        paddle.add(z=1)
+        paddle.add(paddle.to.api, paddle.to.api())
         '''
         expected_src = '''
         paddle.add(x=1,y=2)
-        paddle.add(x=1,y=2)
+        paddle.add(x=1, y=2)
+        paddle.add(x=1, y=2)
+        paddle.add(x=1)
+        paddle.add(z=1)
+        paddle.add(x=paddle.to.api, y=paddle.to.api())
         '''
         self._run(self.change_spec, input_src, expected_src)
 
@@ -227,7 +219,7 @@ class TestRefactorKwargs(unittest.TestCase):
                 [ "", "name", "test" ]
             ],
             "args_warning": {
-                "x_new": "x_new is deleted in paddle.kron"
+                "x_new": "x_new is deleted in paddle.add"
             }
         }
     }
@@ -253,6 +245,20 @@ class TestRefactorKwargs(unittest.TestCase):
         '''
         self._run(self.change_spec, input_src, expected_src)
 
+        input_src = '''
+        # comment line1
+        # comment line2
+        # comment line3
+        paddle.add(x=1, out=2)
+        '''
+        expected_src = '''
+        # comment line1
+        # comment line2
+        # comment line3
+        paddle.add(x_new=1, name=test)
+        '''
+        self._run(self.change_spec, input_src, expected_src)
+
 
 class TestWithRefactor(unittest.TestCase):
     change_spec = {}
@@ -278,9 +284,11 @@ class TestWithRefactor(unittest.TestCase):
 
         paddle.disable_static(place)
         pass
+        paddle.enable_static()
 
         paddle.disable_static()
         pass
+        paddle.enable_static()
         '''
         self._run(self.change_spec, input_src, expected_src)
 
@@ -301,10 +309,12 @@ class TestWithRefactor(unittest.TestCase):
         paddle.disable_static(place)
         pass
         pass
+        paddle.enable_static()
 
         paddle.disable_static()
         pass
         pass
+        paddle.enable_static()
         '''
         self._run(self.change_spec, input_src, expected_src)
 
@@ -328,11 +338,13 @@ class TestWithRefactor(unittest.TestCase):
         pass
         pass
         pass
+        paddle.enable_static()
 
         paddle.disable_static()
         pass
         pass
         pass
+        paddle.enable_static()
         '''
         self._run(self.change_spec, input_src, expected_src)
 
@@ -357,12 +369,14 @@ class TestWithRefactor(unittest.TestCase):
         paddle.disable_static(place)
         pass
         pass
+        paddle.enable_static()
 
         # comment line2
         # comment line3
         paddle.disable_static()
         pass
         pass
+        paddle.enable_static()
         '''
         self._run(self.change_spec, input_src, expected_src)
 
@@ -390,12 +404,103 @@ class TestWithRefactor(unittest.TestCase):
                 paddle.disable_static()
                 pass
                 pass
+                paddle.enable_static()
                 pass
             else:
                 pass
         '''
         self._run(self.change_spec, input_src, expected_src)
 
+        input_src = '''
+        import paddle
+        if True is True:
+            with fluid.dygraph.guard():
+                if True is True:
+                    pass
+
+            pass
+        pass
+        '''
+        expected_src = '''
+        import paddle
+        if True is True:
+            paddle.disable_static()
+            if True is True:
+                pass
+            paddle.enable_static()
+
+            pass
+        pass
+        '''
+        self._run(self.change_spec, input_src, expected_src)
+
+
+class TestActTransformer(unittest.TestCase):
+    maxDiff = None
+    change_spec = {
+        "paddle.Conv2D": {
+            "args_change": [
+                [ "act", "" ],
+            ],
+        },
+        "paddle.elementwise_add": {
+            "args_change": [
+                [ "act", "" ],
+            ],
+        },
+    }
+
+    def _run(self, change_spec, input_src, expected_src):
+        input_src = textwrap.dedent(input_src).strip() + '\n'
+        expected_src = textwrap.dedent(expected_src).strip() + '\n'
+        output_src = _refactor_helper(refactor_kwargs, input_src, change_spec)
+        self.assertEqual(output_src, expected_src)
+
+    def test_act_transformer(self):
+        input_src = '''
+        import paddle
+
+        visible_act = "relu"
+
+        class SimpleImgConvPool():
+            def __init__(self, act=None):
+                self._conv2d_1 = paddle.Conv2D(act=act)
+                self._conv2d_2 = paddle.Conv2D(act="relu")
+                self._conv2d_3 = paddle.Conv2D(act=None)
+
+            def forward(self, x):
+                x = self._conv2d_1(x)
+                x = self._conv2d_2(x)
+                x = self._conv2d_3(x)
+                x = paddle.elementwise_add(x, act="softmax")
+                x = paddle.elementwise_add(x, act=visible_act)
+                return x
+        '''
+        expected_src = '''
+        import paddle
+
+        visible_act = "relu"
+
+        class SimpleImgConvPool():
+            def __init__(self, act=None):
+                self._conv2d_1 = paddle.Conv2D()
+                self._act = act
+                self._conv2d_2 = paddle.Conv2D()
+                self._conv2d_3 = paddle.Conv2D()
+
+            def forward(self, x):
+                x = self._conv2d_1(x)
+                x = getattr(paddle.nn.functional, self._act)(x) if self._act else x
+                x = self._conv2d_2(x)
+                x = paddle.nn.functional.relu(x)
+                x = self._conv2d_3(x)
+                x = paddle.elementwise_add(x)
+                x = paddle.nn.functional.softmax(x)
+                x = paddle.elementwise_add(x)
+                x = getattr(paddle.nn.functional, visible_act)(x) if visible_act else x
+                return x
+        '''
+        self._run(self.change_spec, input_src, expected_src)
 
 
 if __name__ == '__main__':
